"""This Python module implements the code related to the following scientific paper:

F. Ragusa, A. Furnari, S. Battiato, G. Signorello, G. M. Farinella, Egocentric Visitors Localization in Cultural Sites, submitted to ACM Journal on Computing and Cultural Heritage (JOCCH)

More information is available at our web page: http://iplab.dmi.unict.it/VEDI/

The module is designed to work with Python 2.7"""

import os
import numpy as np
import egolocseg as ego
from sklearn.metrics import f1_score
import shutil



dir = "4_Evaluation/output"
if os.path.exists(dir):
	shutil.rmtree(dir)
os.makedirs(dir)


#Delete negatives in CNN_classification

inp = open('1_Discrimination/output/CNN_classification_mod.txt', 'r')
out = open('1_Discrimination/output/CNN_without_negatives.txt', 'a')

count = 0
size = len(os.listdir("frames"))

for i in range(1,size):

	tmp = inp.readline()
	if(i<3):
		out.write(tmp)
		count+=1

print count
inp.close()
out.close()

#Delete negatives in Ground Truth

inp = open('ground_truth.txt', 'r')
out = open('4_Evaluation/output/ground_truth_without_negatives.txt', 'a')

count = 0
for i in range(1,size):

	tmp = inp.readline()
	if(i<3):
		out.write(tmp)
		count+=1

print count
inp.close()
out.close()
####################################################

#eval Discrimination

print("eval DISCRIMINATION")
gt_labels = np.loadtxt('4_Evaluation/output/ground_truth_without_negatives.txt')
predicted_labels = np.loadtxt('1_Discrimination/output/CNN_without_negatives.txt')

#SF1 score

print("SF1 score:")
SF1 = ego.SF1(gt_labels, predicted_labels)
print SF1[1]
print SF1[1].mean()

#FF1 score

print("FF1 score:")
print f1_score(gt_labels, predicted_labels, average=None)
print f1_score(gt_labels, predicted_labels, average=None).mean()

##################################################

#eval Rejection

print("eval REJECTION")
gt_labels = np.loadtxt('ground_truth.txt')
predicted_labels = np.loadtxt('2_NegativeRejection/output/labels_rejection.txt')

#SF1 score

print("SF1 score:")
SF1 = ego.SF1(gt_labels, predicted_labels)
print SF1[1]
print SF1[1].mean()

#FF1 score

print("FF1 score:")
print f1_score(gt_labels, predicted_labels, average=None)
print f1_score(gt_labels, predicted_labels, average=None).mean()

#################################################

#eval HMM

print("eval HMM")
predicted_labels = np.loadtxt('3_SequentialModeling/output/viterbi_sequential_mod.txt')

#SF1 score

print("SF1 score:")
SF1 = ego.SF1(gt_labels, predicted_labels)
print SF1[1]
print SF1[1].mean()

#FF1 score

print("FF1 score:")
print f1_score(gt_labels, predicted_labels, average=None)
print f1_score(gt_labels, predicted_labels, average=None).mean()